@@ -1,14 +1,10 @@
-from functools import wraps
-from typing import Callable, Awaitable
-
-
 class AnyPayAPIError(Exception):
     """
     Base AnyPay Exception.
     Exception codes and their meanings can be found here: https://anypay.io/doc/api/errors
     """
     
-    def __init__(self, exception: dict) -> None:
+    def __init__(self, exception: dict):
         """
         AnyPay API Exception.
         Docs: https://anypay.io/doc/api/errors
