@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Optional
 
 from pydantic import BaseModel
 from pydantic.fields import Field
@@ -11,6 +11,6 @@ class Bill(BaseModel):
     """
 
     id: int = Field(..., alias='pay_id')
-    transaction_id: Union[int, None] = None
+    transaction_id: Optional[int] = None
     status: str = 'waiting'
     url: str = Field(..., alias='payment_url')
