@@ -1,3 +1,5 @@
+from typing import Dict
+
 from pydantic import BaseModel
 from pydantic.fields import Field
 
@@ -7,5 +9,5 @@ class Rates(BaseModel):
     Model of rates
     """
 
-    in_: dict[str, float] = Field(..., alias='in')
-    out: dict[str, float]
+    in_: Dict[str, float] = Field(..., alias='in')
+    out: Dict[str, float]
